==> libgnome-1.105.0.tar.gz: libgnome-1.105.0/libgnome/libgnome.h <==
/*
 * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
 * All rights reserved.
 *
 * This file is part of the Gnome Library.
 *
 * The Gnome Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Gnome Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Gnome Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
/*
  @NOTATION@
 */

#ifndef LIBGNOME_H
#define LIBGNOME_H

#include <libgnome/gnome-program.h>
#include <libgnome/gnome-i18n.h>

#include <libgnome/gnome-config.h>

#include <libgnome/gnome-gconf.h>

#include <libgnome/gnome-help.h>

#include <libgnome/gnome-macros.h>

#include <libgnome/gnome-triggers.h>
#include <libgnome/gnome-sound.h>

#include <libgnome/gnome-score.h>

#include <libgnome/gnome-exec.h>

#include <libgnome/gnome-util.h>
#include <libgnome/gnome-url.h>

#include <libgnome/gnome-marshal.h>

#include <libgnome/gnome-init.h>

#endif /* LIBGNOME_H */

==> libgnome2-1.103.0.tar.gz: libgnome2-1.103.0/libgnome/libgnome.h <==
/*
 * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
 * All rights reserved.
 *
 * This file is part of the Gnome Library.
 *
 * The Gnome Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Gnome Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Gnome Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
/*
  @NOTATION@
 */

#ifndef LIBGNOME_H
#define LIBGNOME_H

#include <libgnome/gnome-program.h>
#include <libgnome/gnome-i18n.h>

#include <libgnome/gnome-config.h>

#include <libgnome/gnome-gconf.h>

#include <libgnome/gnome-help.h>

#include <libgnome/gnome-triggers.h>
#include <libgnome/gnome-sound.h>

#include <libgnome/gnome-score.h>

#include <libgnome/gnome-exec.h>

#include <libgnome/gnome-util.h>
#include <libgnome/gnome-url.h>

#include <libgnome/gnome-preferences.h>
#include <libgnome/gnome-marshal.h>

#include <libgnome/gnome-init.h>

#endif /* LIBGNOME_H */
